@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2007-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2007-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "csharpwriter.h"
@@ -118,12 +118,13 @@ QStringList CSharpWriter::defaultDatatypes() const
     l.append(QLatin1String("char"));
     l.append(QLatin1String("decimal"));
     l.append(QLatin1String("double"));
-    l.append(QLatin1String("fixed"));
-    l.append(QLatin1String("float"));
+    l.append(QLatin1String("dynamic"));
     l.append(QLatin1String("fixed"));
     l.append(QLatin1String("float"));
     l.append(QLatin1String("int"));
     l.append(QLatin1String("long"));
+    l.append(QLatin1String("nint"));
+    l.append(QLatin1String("nuint"));
     l.append(QLatin1String("object"));
     l.append(QLatin1String("sbyte"));
     l.append(QLatin1String("short"));
@@ -131,6 +132,25 @@ QStringList CSharpWriter::defaultDatatypes() const
     l.append(QLatin1String("uint"));
     l.append(QLatin1String("ulong"));
     l.append(QLatin1String("ushort"));
+    l.append(QLatin1String("bool[]"));
+    l.append(QLatin1String("byte[]"));
+    l.append(QLatin1String("char[]"));
+    l.append(QLatin1String("decimal[]"));
+    l.append(QLatin1String("double[]"));
+    l.append(QLatin1String("dynamic[]"));
+    l.append(QLatin1String("fixed[]"));
+    l.append(QLatin1String("float[]"));
+    l.append(QLatin1String("int[]"));
+    l.append(QLatin1String("long[]"));
+    l.append(QLatin1String("nint[]"));
+    l.append(QLatin1String("nuint[]"));
+    l.append(QLatin1String("object[]"));
+    l.append(QLatin1String("sbyte[]"));
+    l.append(QLatin1String("short[]"));
+    l.append(QLatin1String("string[]"));
+    l.append(QLatin1String("uint[]"));
+    l.append(QLatin1String("ulong[]"));
+    l.append(QLatin1String("ushort[]"));
     return l;
 }
 
@@ -141,7 +161,7 @@ QStringList CSharpWriter::defaultDatatypes() const
 void CSharpWriter::writeClass(UMLClassifier *c)
 {
     if (!c) {
-        uDebug() << "Cannot write class of NULL concept!";
+        logWarn0("CSharpWriter::writeClass: Cannot write class of NULL concept");
         return;
     }
 
@@ -453,10 +473,10 @@ void CSharpWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAs
 
 /**
  * Write a list of class operations.
- * @param opList the list of operations
- * @param cs output stream
- * @param interface indicates if the operation is an interface member
- * @param isOverride implementation of an inherited abstract function
+ * @param opList            the list of operations
+ * @param cs                output stream
+ * @param isInterface       indicates if the operation is an interface member
+ * @param isOverride        implementation of an inherited abstract function
  * @param generateErrorStub flag whether an exception should be thrown
  */
 void CSharpWriter::writeOperations(UMLOperationList opList,
@@ -658,7 +678,7 @@ void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UML
 
         UMLObject *o = a->getObject(Uml::RoleType::B);
         if (o == 0) {
-            uError() << "composition role B object is NULL";
+            logError0("composition role B object is NULL");
             continue;
         }
         // Take name and documentation from Role, take type name from the referenced object
@@ -747,7 +767,7 @@ void CSharpWriter::writeAttribute(const QString& doc,
 
 /**
  * Find the type in used namespaces, if namespace found return short name, complete otherwise.
- * @param at Operation or Attribute to check type
+ * @param cl Operation or Attribute to check type
  */
 QString CSharpWriter::makeLocalTypeName(UMLClassifierListItem *cl)
 {
