@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -273,7 +273,7 @@ void ListPopupMenu::insert(const MenuType m, KMenu* menu)
     case mt_UseCase_Folder:             LPMIBI(it_Folder,                i18n("Folder")); break;
 
     default:
-        uWarning() << "called on unimplemented MenuType " << toString(m);
+        logWarn1("ListPopupMenu::insert called on unimplemented MenuType %1", toString(m));
         break;
     }
 #undef LPMISI
@@ -410,7 +410,7 @@ ListPopupMenu::MenuType ListPopupMenu::typeFromAction(QAction *action)
         return menu->getMenuType(action);
     }
     else {
-        uError() << "Action's data field does not contain ListPopupMenu pointer!";
+        logError0("typeFromAction: Action's data field does not contain ListPopupMenu pointer!");
         return mt_Undefined;
     }
 }
@@ -563,7 +563,7 @@ void ListPopupMenu::setActionChecked(MenuType idx, bool value)
         action->setChecked(value);
     }
     else {
-        DEBUG(DBG_SRC) << "called on unknown MenuType " << toString(idx);
+        DEBUG() << "called on unknown MenuType " << toString(idx);
     }
 }
 
@@ -580,7 +580,7 @@ void ListPopupMenu::setActionEnabled(MenuType idx, bool value)
         action->setEnabled(value);
     }
     else {
-        DEBUG(DBG_SRC) << "called on unknown MenuType " << toString(idx);
+        DEBUG() << "called on unknown MenuType " << toString(idx);
     }
 }
 
